@@ -7,12 +7,11 @@ from distutils.version import LooseVersion
 import pandas as pd
 import pyarrow as pa
 import pyarrow.parquet as pq
-from pyarrow.compat import guid
 from ....utils import getargspec
-
 from ..utils import _get_pyarrow_dtypes, _meta_from_dtypes
 from ...utils import clear_known_categories
 from ....core import flatten
+from dask import delayed
 
 from .utils import (
     _parse_pandas_metadata,
@@ -22,6 +21,7 @@ from .utils import (
 )
 
 preserve_ind_supported = pa.__version__ >= LooseVersion("0.15.0")
+schema_field_supported = pa.__version__ >= LooseVersion("0.15.0")
 
 
 #
@@ -29,14 +29,30 @@ preserve_ind_supported = pa.__version__ >= LooseVersion("0.15.0")
 #
 
 
-def _write_partitioned(table, root_path, partition_cols, fs, index_cols=(), **kwargs):
-    """ Write table to a partitioned dataset with pyarrow.
+def _append_row_groups(metadata, md):
+    try:
+        metadata.append_row_groups(md)
+    except RuntimeError as err:
+        if "requires equal schemas" in str(err):
+            raise RuntimeError(
+                "Schemas are inconsistent, try using "
+                '`to_parquet(..., schema="infer")`, or pass an explicit '
+                "pyarrow schema."
+            )
+        else:
+            raise err
 
-        Logic copied from pyarrow.parquet.
-        (arrow/python/pyarrow/parquet.py::write_to_dataset)
 
-        TODO: Remove this in favor of pyarrow's `write_to_dataset`
-              once ARROW-8244 is addressed.
+def _write_partitioned(
+    table, root_path, filename, partition_cols, fs, index_cols=(), **kwargs
+):
+    """Write table to a partitioned dataset with pyarrow.
+
+    Logic copied from pyarrow.parquet.
+    (arrow/python/pyarrow/parquet.py::write_to_dataset)
+
+    TODO: Remove this in favor of pyarrow's `write_to_dataset`
+          once ARROW-8244 is addressed.
     """
     fs.mkdirs(root_path, exist_ok=True)
 
@@ -72,12 +88,11 @@ def _write_partitioned(table, root_path, partition_cols, fs, index_cols=(), **kw
             subgroup, preserve_index=preserve_index, schema=subschema, safe=False
         )
         prefix = fs.sep.join([root_path, subdir])
-        fs.mkdir(prefix, exists_ok=True)
-        outfile = guid() + ".parquet"
-        full_path = fs.sep.join([prefix, outfile])
+        fs.mkdirs(prefix, exist_ok=True)
+        full_path = fs.sep.join([prefix, filename])
         with fs.open(full_path, "wb") as f:
             pq.write_table(subtable, f, metadata_collector=md_list, **kwargs)
-        md_list[-1].set_file_path(fs.sep.join([subdir, outfile]))
+        md_list[-1].set_file_path(fs.sep.join([subdir, filename]))
 
     return md_list
 
@@ -93,8 +108,10 @@ def _index_in_schema(index, schema):
 
 
 def _get_dataset_object(paths, fs, filters, dataset_kwargs):
-    """ Generate a ParquetDataset object
-    """
+    """Generate a ParquetDataset object"""
+    kwargs = dataset_kwargs.copy()
+    if "validate_schema" not in kwargs:
+        kwargs["validate_schema"] = False
     if len(paths) > 1:
         # This is a list of files
         base, fns = _analyze_paths(paths, fs)
@@ -105,21 +122,14 @@ def _get_dataset_object(paths, fs, filters, dataset_kwargs):
             # open "_metadata" separately.
             paths.remove(fs.sep.join([base, "_metadata"]))
             fns.remove("_metadata")
-            proxy_metadata = (
-                pq.ParquetDataset(
-                    fs.sep.join([base, "_metadata"]),
-                    filesystem=fs,
-                    filters=filters,
-                    **dataset_kwargs,
-                )
-                .pieces[0]
-                .get_metadata()
-            )
+            with fs.open(fs.sep.join([base, "_metadata"]), mode="rb") as fil:
+                proxy_metadata = pq.ParquetFile(fil).metadata
         # Create our dataset from the list of data files.
-        # Note that this will not parse all the files (yet)
-        dataset = pq.ParquetDataset(
-            paths, filesystem=fs, filters=filters, **dataset_kwargs
-        )
+        # Note #1: that this will not parse all the files (yet)
+        # Note #2: Cannot pass filters for legacy pyarrow API (see issue#6512).
+        #          We can handle partitions + filtering for list input after
+        #          adopting new pyarrow.dataset API.
+        dataset = pq.ParquetDataset(paths, filesystem=fs, **kwargs)
         if proxy_metadata:
             dataset.metadata = proxy_metadata
     elif fs.isdir(paths[0]):
@@ -130,19 +140,13 @@ def _get_dataset_object(paths, fs, filters, dataset_kwargs):
         #       expensive in storage systems like S3.
         allpaths = fs.glob(paths[0] + fs.sep + "*")
         base, fns = _analyze_paths(allpaths, fs)
-        if "_metadata" in fns and "validate_schema" not in dataset_kwargs:
-            dataset_kwargs["validate_schema"] = False
-        dataset = pq.ParquetDataset(
-            paths[0], filesystem=fs, filters=filters, **dataset_kwargs
-        )
+        dataset = pq.ParquetDataset(paths[0], filesystem=fs, filters=filters, **kwargs)
     else:
         # This is a single file.  No danger in gathering statistics
         # and/or splitting row-groups without a "_metadata" file
         base = paths[0]
         fns = [None]
-        dataset = pq.ParquetDataset(
-            paths[0], filesystem=fs, filters=filters, **dataset_kwargs
-        )
+        dataset = pq.ParquetDataset(paths[0], filesystem=fs, **kwargs)
 
     return dataset, base, fns
 
@@ -150,11 +154,11 @@ def _get_dataset_object(paths, fs, filters, dataset_kwargs):
 def _gather_metadata(
     paths, fs, split_row_groups, gather_statistics, filters, dataset_kwargs
 ):
-    """ Gather parquet metadata into a single data structure.
+    """Gather parquet metadata into a single data structure.
 
-        Use _metadata or aggregate footer metadata into a single
-        object.  Also, collect other information necessary for
-        parquet-to-ddf mapping (e.g. schema, partition_info).
+    Use _metadata or aggregate footer metadata into a single
+    object.  Also, collect other information necessary for
+    parquet-to-ddf mapping (e.g. schema, partition_info).
     """
 
     # Step 1: Create a ParquetDataset object
@@ -240,7 +244,7 @@ def _gather_metadata(
             elif fn:
                 md.set_file_path(fn)
             if metadata:
-                metadata.append_row_groups(md)
+                _append_row_groups(metadata, md)
             else:
                 metadata = md
         return (
@@ -335,8 +339,8 @@ def _generate_dd_meta(schema, index, categories, partition_info):
 def _aggregate_stats(
     file_path, file_row_group_stats, file_row_group_column_stats, stat_col_indices
 ):
-    """ Utility to aggregate the statistics for N row-groups
-        into a single dictionary.
+    """Utility to aggregate the statistics for N row-groups
+    into a single dictionary.
     """
     if len(file_row_group_stats) < 1:
         # Empty statistics
@@ -500,11 +504,11 @@ def _construct_parts(
     split_row_groups,
     gather_statistics,
 ):
-    """ Construct ``parts`` for ddf construction
+    """Construct ``parts`` for ddf construction
 
-        Use metadata (along with other data) to define a tuple
-        for each ddf partition.  Also gather statistics if
-        ``gather_statistics=True``, and other criteria is met.
+    Use metadata (along with other data) to define a tuple
+    for each ddf partition.  Also gather statistics if
+    ``gather_statistics=True``, and other criteria is met.
     """
 
     parts = []
@@ -822,8 +826,51 @@ class ArrowEngine(Engine):
         partition_on=None,
         ignore_divisions=False,
         division_info=None,
+        schema=None,
+        index_cols=None,
         **kwargs,
     ):
+        # Infer schema if "infer"
+        # (also start with inferred schema if user passes a dict)
+        if schema == "infer" or isinstance(schema, dict):
+
+            # Start with schema from _meta_nonempty
+            _schema = pa.Schema.from_pandas(
+                df._meta_nonempty.set_index(index_cols)
+                if index_cols
+                else df._meta_nonempty
+            )
+
+            # Use dict to update our inferred schema
+            if isinstance(schema, dict):
+                schema = pa.schema(schema)
+                for name in schema.names:
+                    i = _schema.get_field_index(name)
+                    j = schema.get_field_index(name)
+                    _schema = _schema.set(i, schema.field(j))
+
+            # If we have object columns, we need to sample partitions
+            # until we find non-null data for each column in `sample`
+            sample = [col for col in df.columns if df[col].dtype == "object"]
+            if schema_field_supported and sample and schema == "infer":
+                delayed_schema_from_pandas = delayed(pa.Schema.from_pandas)
+                for i in range(df.npartitions):
+                    # Keep data on worker
+                    _s = delayed_schema_from_pandas(
+                        df[sample].to_delayed()[i]
+                    ).compute()
+                    for name, typ in zip(_s.names, _s.types):
+                        if typ != "null":
+                            i = _schema.get_field_index(name)
+                            j = _s.get_field_index(name)
+                            _schema = _schema.set(i, _s.field(j))
+                            sample.remove(name)
+                    if not sample:
+                        break
+
+            # Final (inferred) schema
+            schema = _schema
+
         dataset = fmd = None
         i_offset = 0
         if append and division_info is None:
@@ -907,7 +954,7 @@ class ArrowEngine(Engine):
                         "Previous: {} | New: {}".format(old_end, divisions[0])
                     )
 
-        return fmd, i_offset
+        return fmd, schema, i_offset
 
     @staticmethod
     def write_partition(
@@ -933,12 +980,19 @@ class ArrowEngine(Engine):
         t = pa.Table.from_pandas(df, preserve_index=preserve_index, schema=schema)
         if partition_on:
             md_list = _write_partitioned(
-                t, path, partition_on, fs, index_cols=index_cols, **kwargs
+                t,
+                path,
+                filename,
+                partition_on,
+                fs,
+                index_cols=index_cols,
+                compression=compression,
+                **kwargs,
             )
             if md_list:
                 _meta = md_list[0]
                 for i in range(1, len(md_list)):
-                    _meta.append_row_groups(md_list[i])
+                    _append_row_groups(_meta, md_list[i])
         else:
             md_list = []
             with fs.open(fs.sep.join([path, filename]), "wb") as fil:
@@ -978,6 +1032,6 @@ class ArrowEngine(Engine):
                 _meta = parts[0][0]["meta"]
                 i_start = 1
             for i in range(i_start, len(parts)):
-                _meta.append_row_groups(parts[i][0]["meta"])
+                _append_row_groups(_meta, parts[i][0]["meta"])
             with fs.open(metadata_path, "wb") as fil:
                 _meta.write_metadata_file(fil)
