@@ -105,6 +105,7 @@ def read_sql_table(
 
     if index_col is None:
         raise ValueError("Must specify index column to partition on")
+
     engine_kwargs = {} if engine_kwargs is None else engine_kwargs
     engine = sa.create_engine(uri, **engine_kwargs)
     m = sa.MetaData()
@@ -135,7 +136,7 @@ def read_sql_table(
         # function names get pandas auto-named
         kwargs["index_col"] = index_col.name
 
-    if meta is None:
+    if head_rows > 0:
         # derive metadata from first few rows
         q = sql.select(columns).limit(head_rows).select_from(table)
         head = pd.read_sql(q, engine, **kwargs)
@@ -148,7 +149,10 @@ def read_sql_table(
             return from_pandas(head, npartitions=1)
 
         bytes_per_row = (head.memory_usage(deep=True, index=True)).sum() / head_rows
-        meta = head.iloc[:0]
+        if meta is None:
+            meta = head.iloc[:0]
+    elif meta is None:
+        raise ValueError("Must provide meta if head_rows is 0")
     else:
         if divisions is None and npartitions is None:
             raise ValueError(
@@ -240,7 +244,7 @@ def to_sql(
     compute=True,
     parallel=False,
 ):
-    """ Store Dask Dataframe to a SQL table
+    """Store Dask Dataframe to a SQL table
 
     An empty table is created based on the "meta" DataFrame (and conforming to the caller's "if_exists" preference), and
     then each block calls pd.DataFrame.to_sql (with `if_exists="append"`).
